API reference
=============

:mod:`typeguard`
----------------

.. module:: typeguard

.. autofunction:: check_type

.. autofunction:: check_argument_types

.. autofunction:: check_return_type

.. autodecorator:: typechecked

.. autoclass:: TypeChecker

.. autoexception:: TypeHintWarning

.. autoexception:: TypeWarning

.. autoclass:: ForwardRefPolicy
    :members:

:mod:`typeguard.importhook`
---------------------------

.. module:: typeguard.importhook

.. autoclass:: TypeguardFinder
    :members:

.. autofunction:: install_import_hook
